<?php
/*
Plugin Name: Covert Video Content
Description: Auto-blogging plugin that will fill your Covert Video Press themed sites with content from YouTube ... and more on autopilot. You can also use the Covert Video Content plugin to import a batch of videos for editing.
Version: 2.4
Author: IM Wealth Builders Ltd
Author URI: http://imwealthbuilders.com/newplugins

Copyright 2021  IM Wealth Builders

*/

define('IMWB_CTC_VERSION', '2.4');
define('IMWB_CTC_FOLDER', 'covertvideocontent');
define('IMWB_CTC_PREFIX', 'imwb_');

/**
 * This is where you add comments for your plugin class
 * @author John Merrick
 */
class IMWB_Covert_Video_Content {
	/**
	 * This value will be used for
	 * - the gettext textdomain
	 * - the subfolder when adding scripts and styles
	 * - the handle for scripts and styles
	 * Please make sure that this value corresponds to the folder name where your plugin resides.
	 * @var string
	 */
	 var $plugin_name = "";
	 var $plugin_url = "";
	 var $update;
	 var $options = Array();
	 var $all_modules = Array("YouTube" => "youtube", "Dailymotion" => "dailymotion", "Vimeo" => "vimeo");
	 var $available_modules = Array();
	 var $current_theme = "";

	/**
	 * The constructor is executed when the class is instatiated and the plugin gets loaded.
	 * @return void
	 */
	function __construct() {

	   $this->plugin_name = IMWB_CTC_PREFIX.IMWB_CTC_FOLDER;

   	// Hack to avoid firing on Admin Login or Registration page
   	if ( in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) )
   	   return;

   	$this->plugin_url = plugins_url(basename( dirname( __FILE__)));

      $this->options = $this->get_admin_options();
      $this->options['createtags'] = empty($this->options['createtags']) ? 'N' : $this->options['createtags'];
     	$this->load_modules();

      if(is_admin()) {
         // Get Update Information
      	$this->get_update_info();
      	add_action('admin_notices', array(&$this, 'admin_warnings'));
      	add_action('admin_menu', array(&$this,'init_admin_menu'));
		   add_action('admin_init', array(&$this,'init_admin'));
      }

      $this->current_theme = IMWB_Covert_Video_Content_get_theme_name();
	}

	/**
	 * Register the admin option page stylesheet and scripts
	 */
	function init_admin() {

	   wp_register_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/admin_options_page.css');
	   wp_register_script($this->plugin_name . '-script', $this->plugin_url.'/scripts/admin_options_page.js');

	}

   /**
    * Scan the modules folder and see which ones are available
    *
    */
   function load_modules() {

      foreach ($this->all_modules as $moduleName => $moduleFile) {
         if(@file_exists(WP_PLUGIN_DIR.'/'.IMWB_CTC_FOLDER."/modules/".$moduleFile.".php")) {
            @require_once(WP_PLUGIN_DIR.'/'.IMWB_CTC_FOLDER."/modules/".$moduleFile.".php");
            $moduleClass = "IMWB_Covert_Video_Content_".$moduleFile;
            $this->available_modules[$moduleName] = new $moduleClass($this);

         }
      }
   }

	function admin_warnings() {

		 if(empty($this->options['keywords']) && !isset($_POST['submit']) ) {
				echo "<div id='update-nag' class='update-nag'><strong>Covert Video Content is almost ready</strong> ".sprintf(__('You must <a href="%1$s">enter your keywords</a> and configure the settings.'), "options-general.php?page=imwb_covertvideocontent-admin-menu")."</div>";
			}
	}

	//Returns an array of admin options
	function get_admin_options() {
		$adminOptions = array('keywords' => '',
		                      'posttype' => '0',
		                      'authors' => '',
		                      'firstnames' => 'David,Judith,John,Patricia,Gwendolyn,Sasha,Laura,Evelyn,Ramona,Kevin,Sara,Shannon,Leon,Corinne,Rachal,Charla,Roscoe,Lawrence,Iluminada,Lee,Maria,Billie,Jessica,Earnest,Mary,Geraldine,Tristan,Julie,Linda,Paul,Hope,Eldridge,Virginia,Gerald,Norma,Leslie,Sandra,Betty,Rozella,Joyce,Jerry,Cathy,Loren,Maria,Joel,Thomas,Diane,Mary,Kenneth,Sandy,Mary,Elizabeth,Chris,Byron,Steve,John,Helen,Keith,Walter,Edward,Rebecca,Mellisa,Ina,Ruby,Cathy,Douglas,Malcom,James,Dale,Stephanie,Elizabeth,Deana,Courtney,Ashley,Walter,Arturo,Daniel,George,Jeffrey,Helen,James,Harold,Bettye,Jack,Edith,Carol,Enrique,William,Jacqueline,Mirella,Joyce,Linda,Courtney,Isabel,Sara,Jennifer,Wilma,Theresa,Edgar,Jesus,John,Jennifer,Randy,Walter,Kathleen,Jason,Patricia,Mollie,Brandy,Marian,Michael,William,Charles,Lynn,Carma,Amanda,Helen,Susan,Richard,Lisa,James,Robin,Matthew,Robert,Debra,Christine,Lisa,Larry,Raymond,Regina,Marcela,Stephanie,Luz,Rachel,Brian,Jessica,Yolanda,Douglas,Flora,Mary,Lindsey,Beverly,Marisol,Kevin,Elmer,Lydia,Linda,Javier,Heather,Glen,Doris,Cathy,William,Leonard,Nicolas,Jessica,Thomas,Patrick,Ramona,Mary,Romeo,Harold,Julianne,Jeffrey,Patricia,Pedro,Angela,Ashley,James,Hugh,Lynn,Michael,Todd,Leo,Fannie,Kay,Luciana,Anthony,Joyce,Joshua,Pamela,Tracy,Jerome,Jeff,Michael,Alberta,Cheryl,William,Jamie,Darryl,Steven,Angie,Reginald,Jose,Nancy,Deborah,Shirley,James,Robert,Alvin',
		                      'lastnames' => 'Lane,Donnell,McCoy,Galloway,Bates,Scott,Carpenter,Sparks,Green,Hughes,Hardin,Turner,Ochoa,North,Kozak,Burns,Jacobsen,King,Zielinski,Ponce,Glover,Pittman,Williams,Rodriguez,Blackmore,Daniels,Hernandez,Rodriguez,Post,Buckley,Thomas,Boyland,Martinez,Weaver,Meneses,Malley,Logan,Coburn,Turner,Nelson,Mazzone,King,Wyatt,McDaniel,Quinn,Anderson,Delgadillo,Shaw,Bryant,Childress,Jones,Reed,Hague,Dreher,Whorton,Pounders,Upton,Wojcik,Ellingsworth,Cobbs,Matthews,Wells,Hale,Gilliland,Knowles,Grissett,Picklesimer,Sibley,Bernal,Davis,Bravo,Stone,Pinkerton,Chatfield,Braxton,Stephens,Robinson,Aoki,Jones,Cervantes,Davis,Brown,Fleming,Petty,Buxton,Serrano,Chance,Martin,Fleetwood,Sainz,Lynch,Parris,Tipton,West,Mitchell,Holland,Watt,Carter,Daniels,Strayhorn,David,Rodriguez,Patterson,Smoot,Richards,Rowe,Weston,Moore,Hernandez,McClain,Moore,Young,Arbour,Moore,Ibarra,Heaton,Sullivan,Stubbs,Schick,Chesnut,Bowman,White,Epling,Mackenzie,Ramsey,McAllister,Lawson,Dunbar,Valverde,Mudge,Gomez,Grant,Ford,Richey,Bailey,Kennedy,Roberts,Gordon,Kummer,Villarreal,Johnson,Bailey,Bell,Robinson,Miller,Wessel,Moorman,Hopkins,Esposito,Radtke,Lemon,Rabago,Parker,Olivo,Kelley,Gould,Cooper,Barnhart,Real,Hicks,Tarbell,Roper,Masters,Martin,Ballou,Pinero,Austin,Crawford,McQueen,Alarcon,Cobb,Marin,Diaz,Clauson,Blay,Foley,Robie,Ford,Jackson,Getty,Fitzgerald,Meyer,Rivera,Robertson,Mabry,Smallwood,Bush,Scott,Lozada,Rudolph,Ramos,Smith,Stephens,January,Dubois,Jenkins,Metz,Gill,Paolucci,Dodson',
		                      'createtags' => 'N',
		                      'badtags' => 'and,here,this,that,then,make,what,which,where,when,does,with,while,your,other,will',
		                      'addcomments' => 'N',
		                      'randcomments' => 'N',
		                      'storeimg' => 'N',
		                      'ratingfrom' => '1',
		                      'ratingto' => '5',
		                      'viewsfrom' => '200',
		                      'viewsto' => '500',
		                      'useapivc' => 'N',
		                      'lastkw' => 0,
		                      'autoplay' => '1',
		                      'showthumbs' => '1',
		                      'thumbpos' => '1',
		                      'videopos' => '1',
		                      'ytmodestbrand' => '0');

		$devOptions = get_option($this->plugin_name."-AdminOptions");
		if (!empty($devOptions)) {
			foreach ($devOptions as $key => $option)
				$adminOptions[$key] = $option;
		}
		update_option($this->plugin_name."-AdminOptions", $adminOptions);
		return $adminOptions;
	}


   /**
    * Loading the Admin side javascripts
    * /scripts/admin_options_page.js from the plugin directory.
    * @return void
    */

   function load_admin_scripts() {
   	// Only enqueue scripts on frontend.
   	wp_enqueue_script('jquery');
   	wp_enqueue_script($this->plugin_name . '-script');

   	wp_localize_script('imwb_ctc_admin_options_script', 'IMWB_CTC_Ajax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'nonce' => wp_create_nonce( 'imwb_ctc_clear_cookie_nonce' ), 'plugin_url' => $this->plugin_url, 'wp_root' => $this->get_wp_root_path() ) );
   }

	/*
	 * Will only be called on our plugin admin page, enqueue our stylesheet here
	 */
	function load_admin_styles() {
        wp_enqueue_style($this->plugin_name . '-stylesheet');
	}


	/**
	 * Adds a new menu with the name "My Admin Menu" and let's anyone that
	 * can publish posts be able to use it.
	 * @return void
	 */
	function init_admin_menu() {

   	$view_hook_name = add_menu_page( 'Covert Video Content Admin Menu',
   	    'Covert Video Content',
   	    'manage_options',
   	    $this->plugin_name . '-admin-menu',
   	    array(&$this, 'load_menu_page'),
   	    'dashicons-playlist-video',
   	    338);
   	$this->views[$view_hook_name] = '1';

   	add_action( 'admin_print_styles-' . $view_hook_name, array(&$this, 'load_admin_styles'));
   	add_action( 'admin_print_scripts-' . $view_hook_name, array(&$this, 'load_admin_scripts'));

   	$view_hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert Video Content Settings', 'Settings', 'manage_options', $this->plugin_name . '-admin-menu', array(&$this, 'load_menu_page'));
   	$this->views[$view_hook_name] = '1';
   	add_action( 'admin_print_styles-' . $view_hook_name, array(&$this, 'load_admin_styles'));
   	add_action( 'admin_print_scripts-' . $view_hook_name, array(&$this, 'load_admin_scripts'));

      foreach ($this->available_modules as $moduleName => $moduleClass) {
         $view_hook_name = $moduleClass->init_admin_menu();
         add_action( 'admin_print_styles-' . $view_hook_name, array(&$this, 'load_admin_styles'));
         add_action( 'admin_print_scripts-' . $view_hook_name, array(&$this, 'load_admin_scripts'));
      }
	}

	/**
	 * This function will be executed when the admin page is to be loaded
	 * @return void
	 */
	 function load_menu_page() {

	    $this->currentBarNum = $this->views[current_filter()];

	 	// Include the HTML from a separate file to keep the plugin class clean
	 	require "pages/admin_options_page.php";
	 }

	function get_wp_root_path()
	{
	    $path = parse_url(get_bloginfo('wpurl'), PHP_URL_PATH);
	    if(!isset($path))
	       return '/';
	    else
	  	    return $path;
	}

	// Function to get a list of the Blogs Categories and return a UL list of them
	function get_blog_categories($parentId = 0, $selected=array()) {
	   $retStr = '';

	if(!is_array($selected))
	   $selected = array();

		$cats = get_categories('hide_empty=0&child_of='.$parentId.'&parent='.$parentId);
	   if(count($cats) > 0){
	      foreach($cats as $cat){
   	      $retStr.= "<option value='" . $cat->cat_ID . "'";
	         if( in_array($cat->cat_ID, $selected ) )
	         {
	         	$retStr .= " selected='selected' ";
	         }
	         $retStr .= " >" .($parentId > 0 ? '&nbsp;&nbsp;- ' :'').esc_html($cat->cat_name). "</option>";

            $retStr .= $this->get_blog_categories($cat->cat_ID, $selected).'</li>';
	      }
	   }

	   return $retStr;
	}

	function get_update_info() {
	   // Include Update Class
	   require_once('imwb-plugin-update-checker-no-lic.php');
	   $gdd21ed = __FILE__;

	   $this->update=new ImwbPluginUpdateChecker_nolic($gdd21ed,'covertvideocontent','plugin-update');
	}


	function generate_password($length)
	{
	   $chars = '.!,$%^&*@';
	   $clen = strlen($chars);
	   $password = substr(base_convert(substr(md5(microtime()),1),16,36),0,$length);
	   $len = strlen($password);

	   for($i = 0;$i < $len;$i++)
	   {
	      if(rand(0,1) & 1)
	         $password[$i] = strtoupper($password[$i]);
      	elseif(rand(0,2) & 1 && $clen)
	         $password[$i] = $chars[rand(0,$clen)];
	   }
	   return $password;
	}

	function get_next_keyword() {
	   $keywords = preg_split("/\n+/", stripslashes($this->options['keywords']));

	   if($this->options['lastkw'] >= count($keywords))
	      $this->options['lastkw'] = 0;

	   $keyword = $keywords[$this->options['lastkw']];

	   $this->options['lastkw']++;
	   update_option($this->plugin_name."-AdminOptions", $this->options);

	   return $keyword;
	}

	function get_next_category($catIds, &$lastcat) {

	   $categories = explode(',', $catIds);

	   if($lastcat >= count($categories))
	      $lastcat = 0;

	   $category = $categories[$lastcat];

	   $lastcat++;

	   return $category;
	}

	function get_post_categories($catIds, $catSelType, $keyword = null) {

	   $categories = explode(',', $catIds);

      if($catSelType == 'R')
   	   $post_categories = Array($categories[rand(0, count($categories)-1)]);
      else if($catSelType == 'M')
         $post_categories = $this->get_category_by_keyword($keyword);
   	else
   	   $post_categories = $categories;

	   return $post_categories;
	}

	function get_category_by_keyword($keyword) {

      $keyword = str_replace(array('"', "'"),'', $keyword );
	   // If no keyword then
	   if(empty($keyword))
	      return '';

	   $categories = get_categories(array('hide_empty'=>0));

	   foreach($categories as $category) {

	      if (strcasecmp($keyword, $category->name) == 0)
	         return Array($category->cat_ID);

         if (strcasecmp($keyword, $category->slug) == 0)
            return Array($category->cat_ID);
      }

      // Not found so create it
      return Array(wp_create_category($keyword));
	}

	function get_random_author() {

      if(!empty($this->options['authors']))
   	   $authors = explode(',', htmlspecialchars(stripslashes($this->options['authors'])));
   	else
   	   $authors = Array();

	   if(count($authors) == 0) {
      	$adminusers = get_users('role=administrator&number=1');
	      return $adminusers[0]->ID;
	   }

	   $author = $authors[rand(0, count($authors)-1)];

	   return $author;
	}

	function get_tags($content) {


   	$contentTags = array();
   	$badtags =  explode(',', htmlspecialchars(stripslashes($this->options['badtags'])));
  		$badchars = array(",", ":", "(", ")", "]", "[", "?", "!", ";", "-", '"');

  		$content = str_replace($badchars, "", $content);

     	$tags = explode(' ', $content);

   	foreach ($tags as $key => $value) {
   		if (strlen($value) > 3) {
   			if (!in_array(strtolower($value), $badtags)) {
   				$contentTags[] = $value;
   			}
   		}
   	}

   	return $contentTags;
   }

	function save_image_locally($url) {

		$contents = @file_get_contents($url);
		$filename = substr(md5(time()), 0, 10)."_".basename($url);
		$filename = str_replace(" ","",$filename);
		$filename = str_replace("%20","",$filename);
		$filename = str_replace("%","",$filename);
		$filename = str_replace('*',"_",$filename);

		if(strpos($filename, ".") === false) {$filename .= ".jpg";}

		$upload_dir = wp_upload_dir();
		$upload_path = $upload_dir['path'];
		$upload_url = $upload_dir['url'];

		if(is_writable($upload_path) && $contents) {
			file_put_contents($upload_path . '/' . $filename, $contents);
			return $upload_url . '/' . $filename;
		}

		return false;
	}

	function strip_links($text) {
	    $tags = array('a','iframe','script');
	    foreach ($tags as $tag){
	        while(preg_match('/<'.$tag.'(|\W[^>]*)>(.*)<\/'. $tag .'>/iusU', $text, $found)){
	            $text = str_replace($found[0],$found[2],$text);
	        }
	    }
	    return preg_replace('/(<('.join('|',$tags).')(|\W.*)\/>)/iusU', '', $text);
	}

	function do_posts($runNow = false) {

	   if($runNow === false)
   	   require_once ABSPATH . 'wp-admin/includes/taxonomy.php'; /* wp_create_category */

      // Get the next keyword to use
      $keyword = $this->get_next_keyword();

      //Find the active modules
   	foreach ($this->available_modules as $moduleName => $moduleClass) {

   	   if($moduleClass->is_active()) {
            // See if module ready to run
            if($runNow || $moduleClass->is_ready_to_post()) {

               $result = $moduleClass->do_posts($keyword);

               if(is_array($result)) {
                  $message = $result["error"]["module"]." - Reason: ".$result["error"]["reason"]." Message: ".$result["error"]["message"];
                  update_option($this->plugin_name."-".$moduleName."-errors", $message);
               }
               else
                  update_option($this->plugin_name."-".$moduleName."-errors", '');
            }
   	   }
		}

		return true;
	}

   function generate_thumbnail($post_id, $video_type, $video_id) {
   // Remove any current thumbnail
   	delete_post_meta( $post_id, '_video_thumbnail' );

	   if(empty($video_id)) return;

	   $video_thumbnail = '';

	   /* Video file */
	   if($video_type == 'F')
	      $video_thumbnail = ''; // Yeah one day

	   /* YouTube Video */
	   elseif ($video_type == 'Y')
	      $video_thumbnail = $video_id;

	   /* Viemo Video */
	   elseif ($video_type == 'V' ){
       $video_thumbnail = $video_id;
	   }

	   /* DailyMotion Video */
	   elseif ($video_type == 'D' ){

	      $response = wp_remote_get( 'https://api.dailymotion.com/video/' . $video_id . '?fields=thumbnail_url' );
	      if( is_wp_error( $response ) ) {
	         $video_thumbnail = '';
	      } else {
	       $output = json_decode( $response['body']  );
	       $video_thumbnail = strtok($output->thumbnail_url, '?');
	      }
	   }
    /* Metacafe Video */
    elseif ($video_type == 'M' ){

       $response = wp_remote_get('http://www.metacafe.com/api/item/' . $video_id . '/', array( 'sslverify' => false ));
       if( is_wp_error( $response ) ) {
          $video_thumbnail = '';
       } else {
         $xml = new SimpleXMLElement( $response['body'] );
         $result = $xml->xpath( "/rss/channel/item/media:thumbnail/@url" );
         $video_thumbnail = (string) $result[0]['url'];
       }
    }

    // See if need to store the image locally
    if(function_exists('imwb_videopress_get_option')) {
       if(imwb_videopress_get_option('storethumbs') == '1' && !empty($video_thumbnail)) {

          $response = wp_remote_get($video_thumbnail);
          if( !is_wp_error( $response ) ) {
             $upload = wp_upload_bits( basename( $video_thumbnail ), null, $response['body'] );
             $video_thumbnail = $upload['url'];
          }

       }
    }
    add_post_meta( $post_id, '_video_thumbnail', $video_thumbnail, true );

  }

}

/**
 * Register the plugin
 */
 /**
 * Register the plugin
 */
function start_IMWB_Covert_Video_Content() {
  $plugin = new IMWB_Covert_Video_Content();
}
add_action("init", "start_IMWB_Covert_Video_Content");

register_deactivation_hook(__FILE__, 'IMWB_Covert_Video_Content_deactivation');

function IMWB_Covert_Video_Content_deactivation() {
	wp_clear_scheduled_hook(IMWB_CTC_PREFIX.IMWB_CTC_FOLDER.'_cron_event');
}

/**
 * Setup the Cron Job
 */

function IMWB_Covert_Video_Content_Cron_Job() {

 	$ccClass = new IMWB_Covert_Video_Content();
 	$ccClass->do_posts(false);
}

add_action(IMWB_CTC_PREFIX.IMWB_CTC_FOLDER.'_cron_event', 'IMWB_Covert_Video_Content_Cron_Job');

if (!wp_next_scheduled(IMWB_CTC_PREFIX.IMWB_CTC_FOLDER.'_cron_event')) {
	wp_schedule_event( current_time( 'timestamp' ), 'hourly', IMWB_CTC_PREFIX.IMWB_CTC_FOLDER.'_cron_event');
}


function IMWB_Covert_Video_Content_get_theme_name() {


   $theme = wp_get_theme();
   $current_theme_name = $theme->Name;

   $templatePath = get_template_directory();
   $stylesheetPath = get_stylesheet_directory();

   // Check if not a CVP child theme
   if($templatePath != $stylesheetPath) {
      $template_uri = get_template_directory_uri();
      if(stristr($template_uri,"covertvideopress") !== false)
         $current_theme_name = "Covert VideoPress Theme";
   }

   return $current_theme_name;

}

// Setup for cases when theme is not Covert VideoPress
if(!is_admin()) {

   $theme_name = IMWB_Covert_Video_Content_get_theme_name();

   if($theme_name != "Covert VideoPress Theme") {
      // Setup filters, actions etc
      // include script with functionality
      require_once('videopress-plugin.php');

   }
}
