<?php

class IMWB_Covert_Video_Content_dailymotion {

   var $super = null;
   var $module_name = "dailymotion";
   var $plugin_name = "";
   var $plugin_url = "";
   var $options = Array();
   var $dmchannels_options = array('xx' => 'All Channels',
                                   'animals' => 'Animals',
                                   'creation' => 'Arts',
                                   'auto' => 'Auto-Moto',
                                   'news' => 'News & Politics',
                                   'school' => 'College',                                                                   
                                   'shortfilms' => 'Film & TV',                                   
                                   'fun' => 'Funny',
                                   'videogames' => 'Gaming',
                                   'gaylesbian' => 'Gay & Lesbian',                                   
                                   'kids' => 'Kids',
                                   'lifestyle' => 'Lifestyle',                                                                      
                                   'music' => 'Music',
                                   'people' => 'People & Family',
                                   'sport' => 'Sports',
                                   'tech' => 'Tech & Science',                                                                      
                                   'travel' => 'Travel',
                                   'tv' => 'TV',
                                   'webcam' => 'Webcam & Vlogs');
   
   /**
    * The constructor is executed when the class is instatiated and the plugin gets loaded.
    * @return void
    */
   function IMWB_Covert_Video_Content_dailymotion(&$super) {
      $this->super = $super;
      $this->plugin_name = $super->plugin_name;
      $this->plugin_url = $super->plugin_url;
      $this->options = $this->get_admin_options();
      
   }
   
   function get_admin_options() {
   	$adminOptions = array('active' => 'N',
   	                      'posthours' => '4',
   	                      'postcount' => '5',
   	                      'categories' => '',
   	                      'catselecttype' => 'R',
   	                      'ignorekw' => 'N',
   	                      'dmchannel' => 'xx',
   	                      'dmorderby' => 'relevance',
   	                      'lastcat' => 0,
   	                      'lastrun' => 0);
   		
   	$devOptions = get_option($this->plugin_name."-".$this->module_name."-AdminOptions");
   	if (!empty($devOptions)) {
   		foreach ($devOptions as $key => $option)
   			$adminOptions[$key] = $option;
   	}				
   	update_option($this->plugin_name."-".$this->module_name."-AdminOptions", $adminOptions);
   	return $adminOptions;
   }
   
   function is_active(){
   
      return $this->options['active'] == 'Y' ? true : false;
   }
   
   function is_ready_to_post() {
   
      $lastrun = $this->options['lastrun'];
      if($lastrun > 0 && ($this->options['lastrun']+($this->options['posthours']*3600)) >current_time('timestamp') )
            return false;
      
      $this->options['lastrun'] = current_time('timestamp');
               
      update_option($this->plugin_name."-".$this->module_name."-AdminOptions", $this->options);   
      
      return true;
   }
   
   function init_admin_menu() {
      $view_hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert Video Content Dailymotion Settings', 'Dailymotion', 'manage_options', $this->plugin_name . '-admin-menu-'.$this->module_name, array(&$this, 'load_options_page'));	
      
      return  $view_hook_name;
   }
   
   function load_options_page() {   
   	// Include the HTML from a separate file to keep the plugin class clean
   	require "dailymotion_options_page.php";
   }
   
   function do_posts($keyword, $numPosts = 0, $category_input = null, $cats_to_post_to = null, $tags_input = null, $post_status = null, $rating = null, $view_count = null, $keyword_search = null, $use_api_viewCount = null) {
      global $wpdb;
      
      if($numPosts == 0)
         $numPosts = rand(1, $this->options['postcount']);
      $numCreated = 0;
      $maxResults = 20;
      
      $url_keyword = urlencode(trim($keyword));
      $search_param = "&search=".$url_keyword;
      
      if(!empty($keyword_search)) 
         $search_param = '';
      elseif($this->options['ignorekw'] == 'Y')
         $search_param = '';      
      
      if($this->options['dmchannel'] != 'xx' )
         $channel_param = "&channel=".$this->options['dmchannel'];
      else
         $channel_param = "";
    
      // Loop through the result pages until we create enough posts
      $page = 1;
   
      do {
         
         $requestURL = "https://api.dailymotion.com/videos?fields=comments_total,description,id,title,views_total".$search_param.$channel_param."&page=".$page."&limit=".$maxResults."&sort=".$this->options['dmorderby'];
           
//        echo "<br>URL: $requestURL<br>";
//        echo "Num Posts".$numPosts."<br>";
//        echo "==================================<br><br>";
   
         $result = $this->_request($requestURL);
         
         if(is_array($result) && !empty($result["error"])) {return $result;}
         
         if ($result === False) {
            $return["error"]["module"] = "Dailymotion";
   			$return["error"]["reason"] = "No content";
   			$return["error"]["message"] = "No (more) Dailymotion videos found.";	
   			return $return;		
         }
         
   	   foreach($result as $video) {
   
               $video_id = (string)$video->id;
               
               // Get the title
               $post_title = (string)$video->title;
               
               // Check for exisintg post         
      			$results = $wpdb->get_row( $wpdb->prepare("SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key = %s AND meta_value = %s", 'imwb_ctc_dailymotion_id', trim($video_id)) );
      			
      			if(count($results) > 0) 
      			   continue;
               
               // Get the description
               $desc = (string)$video->description;
      			   			
               // get category
               if(empty($cats_to_post_to))
                  $post_category = $this->super->get_post_categories(htmlspecialchars(stripslashes($this->options['categories'])),$this->options['catselecttype'], $keyword);
               else 
                  $post_category = $this->super->get_post_categories($category_input ,$cats_to_post_to, $keyword);
               
            
               // Get The Tags
               if(empty($tags_input)) {
                  $post_tags = array();	
                  if($this->super->options['createtags'] == 'Y') {
                     $post_tags = $this->super->get_tags($post_title);
                  }
               }
               else 
                  $post_tags = $tags_input;
   
               // Save Post
               $post_content = wpautop($desc);
               $post_type = "post";
               $post_date = current_time('mysql');
               $post_date_gmt = current_time('mysql', 1);
               $post_author = $this->super->get_random_author();
               if(empty($post_status))
                  $post_status = $this->super->options['posttype'] == '0' ? 'publish' : 'draft';
   
//              echo "<br>Title: $post_title<br>Content: $post_content<br>CatId:";
//              var_dump($post_category);
//              echo "<br>AuthorId:$post_author<br>Video Id:$video_id<br>";
   
              	$post_data = compact('post_content','post_title','post_date','post_date_gmt','post_author','post_category', 'post_status', 'post_type');	
              		
               $post_data['tags_input'] = implode(',', $post_tags);
               $post_data = add_magic_quotes($post_data);
               $postId = wp_insert_post($post_data);
               if (is_wp_error($postId)) {
                  $return["error"]["module"] = "Dailymotion ($keyword)";
                  $return["error"]["reason"] = "Error Inserting Post";
                  $return["error"]["message"] = $postId->get_error_message();	
                  return $return;
               }
               
               // Store the Video ID so we don't post duplicates
               update_post_meta( $postId , 'imwb_ctc_dailymotion_id', trim($video_id) );
               // Store the video
               update_post_meta( $postId , 'imwb_videopress_post_video_url', trim($video_id) );
               update_post_meta( $postId , 'imwb_videopress_post_video_type', 'D' );
               
               // Set the thumbnail
               $this->super->generate_thumbnail($postId, 'D', trim($video_id));
               
               // Set the view count
               if(!empty($use_api_viewCount) && $use_api_viewCount == 'Y' && $video->views_total > 0)
                  $vc_value = (int)$video->views_total;
               else if(empty($use_api_viewCount) && $this->super->options['useapivc'] == 'Y' && $video->views_total > 0)
                  $vc_value = (int)$video->views_total;
               else {            
                  if(!empty($view_count))
                     $vc_value = mt_rand($view_count['min'], $view_count['max']);
                  else
                     $vc_value = mt_rand($this->super->options['viewsfrom'], $this->super->options['viewsto']);
               }      
                  
//            echo "View Count:$vc_value<br>";
               
               update_post_meta( $postId, '_imwb_videopress_post_video_views', $vc_value);
   
               // Set the rating
               if(!empty($rating)) 
                  $vr_value = mt_rand($rating['min'], $rating['max']);
               else
                  $vr_value = mt_rand($this->super->options['ratingfrom'], $this->super->options['ratingto']);
                  
//            echo "Rating:$vr_value<br>";
                  
               update_post_meta( $postId, '_imwb_videopress_post_video_score', $vr_value);   
               update_post_meta( $postId, '_imwb_videopress_post_video_count', '1');  
               update_post_meta( $postId, '_imwb_videopress_post_video_rating', $vr_value);  
               update_post_meta( $postId, '_imwb_videopress_post_video_imp', 0);
               update_post_meta( $postId, '_imwb_videopress_post_video_clicks', 0);
               update_post_meta( $postId, '_imwb_videopress_post_video_ctr', 0);
               
               $numCreated++;
               
               // Comments
               if ($video->comments_total > 0) {             	
//            echo "Comments:{$video->comments_total}<br><br>";
               
                  if($this->super->options['addcomments'] == 'Y') {
                     $this->do_comments($postId, $video_id, $video->comments_total); 
                  }            
               }     
               
               if( $numCreated == $numPosts)
                  break;
         }
         

         // Page Loop
         if( $numCreated == $numPosts)
            break;         
            
         $page++;
                     
      } while($page <= 30);   
      
      return $numCreated;
   }
   
   function do_comments($postId, $videoid, $commentsCount) {

      $response = wp_remote_get("https://api.dailymotion.com/video/".$videoid."/comments?fields=message,owner.screenname&page=1&limit=50");
      if( is_wp_error( $response ) ) 
         return;

      $result = json_decode($response['body'], true);
            
      $comments = $result['list'];
      
      if(count($comments) <= 0 )
         return;
               
      if($this->super->options['randcomments'] == 'Y') {
      	$half = ceil(50 / 2);
      	$cnum = rand($half,50);
      } else {
      	$cnum = $commentsCount;
      }   

   	$comment_ts = current_time('timestamp');	
   	
      $i = 0;
		foreach ($comments as $comment) {

			if($i == $cnum) 
			   break;
			   
			$comment_post_ID=$postId;
			$comment_ts = $comment_ts + (rand(0, 30) * 60 + rand(0, 59));
         $comment_date = date('Y-m-d H:i:s', $comment_ts);
			$rnd= rand(1,9999);
			$comment_author_email="noreply$rnd@yourdomain.com";
			$comment_author=(string)$comment['owner.screenname'];
			$comment_author_url='';  
			$comment_content=(string)$comment['message'];			
			$comment_type='';
			$user_ID='';
			$comment_approved = 1;
			$commentdata = compact('comment_post_ID', 'comment_date', 'comment_author', 'comment_author_email', 'comment_author_url', 'comment_content', 'comment_type', 'user_ID', 'comment_approved');
			$comment_id = wp_insert_comment( $commentdata );
			$i++;
		}
   }
   
   function _request($request) {
   	
   	$response = wp_remote_get($request);
      if( is_wp_error( $response ) ) {
  	      $return["error"]["module"] = "Dailymotion";
  	      $return["error"]["reason"] = "Error Connecting to Dailymotion API";
  	      $return["error"]["message"] = $response->get_error_message();	
  	      return $return;
     }
     
     $result = json_decode($response['body']);
     
     if(isset($result->error)) {
        $return["error"]["module"] = "Dailymotion";
        $return["error"]["reason"] = "Dailymotion API Error";
        $return["error"]["message"] = $result->error->code." ".$result->error->message." ".$result->error->type;	
        return $return;
     }
     
     $videos = $result->list;
     
     if(count($videos) > 0 )
        return $videos;
     else
        return false;
     
   } 
}


?>