<?php

require_once(WP_PLUGIN_DIR.'/'.IMWB_CTC_FOLDER."/Vimeo/Vimeo.php");

class IMWB_Covert_Video_Content_vimeo {

   var $super = null;
   var $module_name = "vimeo";
   var $plugin_name = "";
   var $plugin_url = "";
   var $options = Array();
   var $num_feed_urls = 6;
   var $vimeoLib;

   /**
    * The constructor is executed when the class is instantiated and the plugin gets loaded.
    * @return void
    */
   function __construct(&$super) {
      $this->super = $super;
      $this->plugin_name = $super->plugin_name;
      $this->plugin_url = $super->plugin_url;
      $this->options = $this->get_admin_options();

      $this->vimeoLib = new Vimeo($this->options['vimeo_client_id'], $this->options['vimeo_client_secret'], null);
   }

   function get_admin_options() {
   	$adminOptions = array('active' => 'N',
   	                      'posthours' => '4',
   	                      'postcount' => '5',
   	                      'requesttype' => 'U',
   	                      'requestparam' => '',
   	                      'catselecttype' => 'R',
   	                      'kwsearch' => 'B',
   	                      'ignorekw' => 'N',
   	                      'lastcat' => 0,
   	                      'lastrun' => 0,
                          'vimeo_client_id' => '',
                          'vimeo_client_secret' => '');

   	$devOptions = get_option($this->plugin_name."-".$this->module_name."-AdminOptions");
   	if (!empty($devOptions)) {
   		foreach ($devOptions as $key => $option)
   			$adminOptions[$key] = $option;
   	}
   	update_option($this->plugin_name."-".$this->module_name."-AdminOptions", $adminOptions);

   	return $adminOptions;
   }

   function is_active(){

      return $this->options['active'] == 'Y' ? true : false;
   }

   function is_ready_to_post() {

      $lastrun = $this->options['lastrun'];
      if($lastrun > 0 && ($this->options['lastrun']+($this->options['posthours']*3600)) >current_time('timestamp') )
            return false;

      $this->options['lastrun'] = current_time('timestamp');

      update_option($this->plugin_name."-".$this->module_name."-AdminOptions", $this->options);

      return true;
   }

   function init_admin_menu() {
      $view_hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert Video Content Vimeo Feed Settings', 'Vimeo', 'manage_options', $this->plugin_name . '-admin-menu-'.$this->module_name, array(&$this, 'load_options_page'));

      return  $view_hook_name;
   }

   function load_options_page() {
   	// Include the HTML from a separate file to keep the plugin class clean
   	require "vimeo_options_page.php";
   }

   function do_posts($keyword, $numPosts = 0, $category_input = null, $cats_to_post_to = null, $tags_input = null, $post_status = null, $rating = null, $view_count = null, $keyword_search = null, $use_api_viewCount = null) {
      global $wpdb;

      $return = null;
      $numCreated = 0;

      if($numPosts == 0)
         $numPosts = rand(1, $this->options['postcount']);

      $page = 1;

      do {

//     echo "Num Posts".$numPosts."<br>";
//     echo "==================================<br><br>";

         $resultxml = $this->_request($page, $keyword);

         if(!empty($resultxml["error"])) {return $resultxml;}

         foreach ($resultxml as $video) {

            // Get the title
            $post_title = trim( $video['name'] );
            $video_id = (string)$video['uri'];
            preg_match('#\/.+\/(.+)#', $video_id, $matches);
            $video_id = $matches[1];

            // Check for exisintg post
            $results = $wpdb->get_row( $wpdb->prepare("SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key = %s AND meta_value = %s", 'imwb_ctc_vimeo_id', trim($video_id)) );

            if(count($results) > 0)
               continue;

            $post_content = trim( $video['description'] );

            // // Do Keyword search
            // if(empty($keyword_search)) {
            //    if($this->options['ignorekw'] != 'Y') {
            //     if(!$this->content_keyword_match($this->options['kwsearch'], $post_title, $post_content, $keyword))
            //        continue;
            //    }
            // }
            // else {
            //    if($keyword_search['ignorekw'] != 'Y') {
            //       if(!$this->content_keyword_match($keyword_search['kwsearch'], $post_title, $post_content, $keyword))
            //          continue;
            //    }
            // }

            // get category
            if(empty($cats_to_post_to))
               $post_category = $this->super->get_post_categories(htmlspecialchars(stripslashes($this->options['categories'])),$this->options['catselecttype'], $keyword);
            else
               $post_category = $this->super->get_post_categories($category_input ,$cats_to_post_to, $keyword);

            // Get The Tags
            if(empty($tags_input)) {
               $post_tags = array();
               if($this->super->options['createtags'] == 'Y') {
                  $post_tags = $this->super->get_tags($post_title);
               }
            }
            else
               $post_tags = $tags_input;

            // Insert Post
            $post_type = "post";
            $post_date = current_time('mysql');
            $post_date_gmt = current_time('mysql', 1);
            $post_author = $this->super->get_random_author();
            if(empty($post_status))
               $post_status = $this->super->options['posttype'] == '0' ? 'publish' : 'draft';

//           echo "Title: $post_title<br>Content: $post_content<br>CatId:";
//           var_dump($post_category);
//           echo "<br>AuthorId:$post_author<br>Video Id:$video_id<br>";

           $post_data = compact('post_content','post_title','post_date','post_date_gmt','post_author','post_category', 'post_status', 'post_type');
           $post_data['tags_input'] = implode(',', $post_tags);
           $post_data = add_magic_quotes($post_data);

           $postId = wp_insert_post($post_data);
           if (is_wp_error($postId)) {
               $return["error"]["module"] = "Vimeo";
               $return["error"]["reason"] = "Error Inserting Post";
               $return["error"]["message"] = $postId->get_error_message();
               return $return;
           }

           // Store the Video ID so we don't post duplicates
           update_post_meta( $postId , 'imwb_ctc_vimeo_id', trim($video_id) );

           // Store the video
           update_post_meta( $postId , 'imwb_videopress_post_video_url', trim($video_id) );
           update_post_meta( $postId , 'imwb_videopress_post_video_type', 'V' );

           // Set the thumbnail
           $this->super->generate_thumbnail($postId, 'V', trim($video['pictures']['sizes'][2]['link']));

           // Set the view count
           if(!empty($use_api_viewCount) && $use_api_viewCount == 'Y' && $video['stats']['plays'] > 0)
              $vc_value = (int)$video['stats']['plays'];
           else if(empty($use_api_viewCount) && $this->super->options['useapivc'] == 'Y' && $video['stats']['plays'] > 0)
              $vc_value = (int)$video['stats']['plays'];
           else {
              if(!empty($view_count))
                 $vc_value = mt_rand($view_count['min'], $view_count['max']);
              else
                 $vc_value = mt_rand($this->super->options['viewsfrom'], $this->super->options['viewsto']);
           }

//           echo "View Count:$vc_value<br>";

           update_post_meta( $postId, '_imwb_videopress_post_video_views', $vc_value);

           // Set the rating
           if(!empty($rating))
               $vr_value = mt_rand($rating['min'], $rating['max']);
           else
               $vr_value = mt_rand($this->super->options['ratingfrom'], $this->super->options['ratingto']);

//           echo "Rating:$vr_value<br>";

           update_post_meta( $postId, '_imwb_videopress_post_video_score', $vr_value);
           update_post_meta( $postId, '_imwb_videopress_post_video_count', '1');
           update_post_meta( $postId, '_imwb_videopress_post_video_rating', $vr_value);
           update_post_meta( $postId, '_imwb_videopress_post_video_imp', 0);
           update_post_meta( $postId, '_imwb_videopress_post_video_clicks', 0);
           update_post_meta( $postId, '_imwb_videopress_post_video_ctr', 0);

           $numCreated++;

           if( $numCreated == $numPosts)
                break;
         }


          // Page Loop
          if( $numCreated == $numPosts)
             break;

          $page++;

       } while($page <= 10);


      if(!empty($return))
         return $return;

      return $numCreated;
   }

   function _request($page, $query) {

     $query = urlencode(trim($query));

     $search_results = $this->vimeoLib->request('/videos', array(
         'page' => $page,
         'per_page' => 50,
         'query' =>  $query,
         'sort' => 'relevant',
         'direction' => 'desc',
         'filter' => 'CC'
     ));

    if( $search_results['status'] != 200 ) {
  	   $return["error"]["module"] = "Vimeo";
  	   $return["error"]["reason"] = "Error Connecting to Vimeo API";
  	   $return["error"]["message"] = $search_results['body']['developer_message'];
  	   return $return;
    }

    return $search_results['body']['data'];
   }
   // function _request($request) {
   //   libxml_use_internal_errors(true);
   //
   // 	 $response = wp_remote_get($request);
   //   var_dump($response);
   //   if( is_wp_error( $response ) ) {
   // 	   $return["error"]["module"] = "Vimeo";
   // 	   $return["error"]["reason"] = "Error Connecting to Vimeo API";
   // 	   $return["error"]["message"] = $response->get_error_message();
   // 	   return $return;
   //   }
   //
   //   $pxml = simplexml_load_string($response['body']);
   //   if ($pxml === False) {
   // 		$emessage = "Failed loading XML, errors returned: ";
   // 		foreach(libxml_get_errors() as $error) {
   // 			$emessage .= $error->message . ", ";
   // 		}
   // 		libxml_clear_errors();
   // 		$return["error"]["module"] = "Vimeo";
   // 		$return["error"]["reason"] = "XML Error";
   // 		$return["error"]["message"] = $emessage;
   // 		return $return;
   // 	} else {
   // 		return $pxml;
   // 	}
   // }

   function content_keyword_match($keyword_search, $post_title, $post_content, $keyword) {

      switch($keyword_search) {
         case 'B': $content = $post_title.' '.$post_content;
                   break;
         case 'T': $content = $post_title;
                   break;
         case 'C': $content = $post_content;
                   break;
      }

      if(stristr($keyword, '"') || stristr($keyword, "'"))
         $words = array(str_replace(array('"', "'"),'', $keyword ));
      else
         $words = array_map('trim', explode(' ', $keyword));

      $match = false;
      foreach($words as $key => $word) {
         $word = "#\b" . trim($word) . "\b#i";
      	if(preg_match_all($word, strip_tags($content), $matches)) {
      		$match = true;
      		break;
      	}
      }

      return $match;

   }

}


?>
