<?php
/*
   Functions for when plugin running in an environment other then Covert Video Press
*/

add_filter('the_content', 'videopress_the_video');
add_action( 'wp_footer', 'videopress_footer', 50 );
add_action('wp_head','videopress_head',50);
add_action('wp_enqueue_scripts', 'videopress_enqueue_scripts');

$videopress_swfobject = null;

function videopress_enqueue_scripts() {
	wp_enqueue_script( 'swfobject' );
	wp_enqueue_script( 'jquery' );
}

function videopress_get_option($element) {
	
   $defaults = array('autoplay' => '1');
	
	$videopress_current_options = get_option('imwb_covertvideocontent-AdminOptions', $defaults);

   if(isset($videopress_current_options[$element]))
		return stripslashes($videopress_current_options[$element]); 
	else if ( isset($defaults[$element]) ) 
		return stripslashes($defaults[$element]); 
	else
		return false;
}


function videopress_get_the_post_thumbnail ( $post_id = null, $thumb_style, $width = '200px', $height = '140px' ) {

   // Get the post ID if none is provided
   if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();
   
   $image_src = videopress_post_thumbnail_img_src ( $post_id);
   
   if(empty($image_src))
      return '';
   
   $attr = apply_filters( 'the_title', get_post_field( 'post_title', $post_id ) );

   $html = '<a href="'.get_permalink($post_id).'">';
   $html.= sprintf('<img src="%s" width="%s" height="%s" title="%s" alt="%s" style="%s">', $image_src, $width, $height,  $attr, $attr, $thumb_style);
   $html.= '</a>';
   
   return $html;

}

function videopress_post_thumbnail_img_src ( $post_id = null, $size = 'imwb-videopress-video-thumb' ) {

   // Get the post ID if none is provided
   if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();

   // If featured image set, use that one
   if(has_post_thumbnail($post_id)) {
      $post_thumbnail_id = get_post_thumbnail_id( $post_id );
      $image_attributes =  wp_get_attachment_image_src($post_thumbnail_id, $size );
      return $image_attributes[0];
   }
      
   
   // If Thumbnail attached then use that one
   if( ( $thumbnail_meta = get_post_meta( $post_id, '_video_thumbnail', true ) ) != '' ) {
   	return $thumbnail_meta;
   }
   
   // Else use default image
   
   return  plugins_url(basename( dirname( __FILE__))) .'/images/default.jpg';

}

function videopress_the_video($content) {
   global $post;
   
   $post_id = $post->ID;

   $video_type = get_post_meta( $post_id, 'imwb_videopress_post_video_type', true );
   $video_url = get_post_meta( $post_id, 'imwb_videopress_post_video_url', true );
   
   if(empty($video_url))
      return $content;
      
   if (!is_single()) {
      if(videopress_get_option('showthumbs') == '0')
         return $content; 
         
      if(videopress_get_option('thumbpos') == '1') 
         $thumb_style = "float: left; margin: 0 5px 5px 0;";
      else
         $thumb_style = "float: right; margin: 0 0 5px 5px;";
         
      return videopress_get_the_post_thumbnail($post_id, $thumb_style).$content;
   }   
   
   $the_video = '';
   
   switch ( $video_type ) {
    case 'D':
       $the_video =  videopress_video_dailymotion($video_url, $post_id);
       break;
   	case 'F':
   		$the_video =  videopress_video_file($video_url, $post_id);
   		break;
    case 'M':
    	$the_video =  videopress_video_metacafe($video_url, $post_id);
    	break;     		
   	case 'Y':
   		$the_video =  videopress_video_youtube($video_url, $post_id);
   		break;
    case 'V':
	      $the_video =  videopress_video_vimeo($video_url, $post_id);     		
   		break;
   }   
   
   
   // Insert video into content
   if(videopress_get_option('videopos') == '1')
      $content = $the_video.$content;
   else
      $content = $content.$the_video;
      
   return $content;
}

 /*
  * Extract the ID from the video url
  */
 function videopress_get_video_id($video_type, $video_url) {

    // YouTube
    if($video_type == 'Y') {
   		// If a URL was passed
   		if ( 'http://' == substr( $video_url, 0, 7 ) || 'https://' == substr( $video_url, 0, 8 )) {
   
          if ( FALSE !== stristr( $video_url, 'youtu.be' ) ) {
   			   preg_match( '#https?://youtu\.be/([\w-]+)#i', $video_url, $matches );
   				if ( empty($matches) || empty($matches[1]) )
   					return '';
   
             return $matches[1];
   			}
   			// Normal video URL
   			else {
   				preg_match( '#https?://(www.youtube|youtube|[A-Za-z]{2}.youtube)\.com/(watch\?v=|w/\?v=|\?v=)([\w-]+)(.*?)#i', $video_url, $matches );
   				if ( empty($matches) || empty($matches[3]) ) 
   				   return '';
   
   				return $matches[3];
   			}
   		}
   		// If a URL wasn't passed, assume a video ID 
   		else {
   		   return $video_url;
   		}
   }
   // Vimeo
   elseif($video_type == 'V') {
   		// If a URL was passed
   		if ( 'http://' == substr( $video_url, 0, 7 ) ) {
   			preg_match( '#http://(www.vimeo|vimeo)\.com(/|/clip:)(\d+)(.*?)#i', $video_url, $matches );
   			if ( empty($matches) || empty($matches[3]) ) 
   			   return '';     
   			
   			return $matches[3];
   		}
   		// If a URL wasn't passed, assume a video ID 
   		else {
   			return $video_url;
   		}
   
   }
   // DailyMotion 
   elseif($video_type == 'D') {
   		if ( 'http://' == substr( $video_url, 0, 7 ) ) {
   			preg_match( '#http://(www.dailymotion|dailymotion)\.com/(.+)/([0-9a-zA-Z]+)\_(.*?)#i', $video_url, $matches );
   			if ( empty($matches) || empty($matches[3]) ) 
   			   return '';
   
   			return $matches[3];
   		}
   	   // If a URL wasn't passed, assume a video ID 
   		else {
   			return $video_url;
   		}
   }
   // Metacafe
   elseif($video_type == 'M') {
   		// If a URL was passed
   		if ( 'http://' == substr( $video_url, 0, 7 ) ) {
   			preg_match( '#http://(www.metacafe|metacafe)\.com/watch/(.*?)/(.*?)#i', $video_url, $matches );
   			if ( empty($matches) || empty($matches[2]) ) 
   			   return '';
   
   			return $matches[2];
   		}
   		// If a URL wasn't passed, assume a video ID was passed instead
   		else {
   			return $video_url;
   		}
 
  }
   
   return '';
}


  function videopress_video_file($video_url, $post_id) {
  
     $video_type = wp_check_filetype($video_url);
     
      // ID is required for multiple videos to work
     	$id = 'video_id_'.rand();
      
      // See what filetype Supplied
      $flv_source = '';
     	$mp4_source = ''; 
  		$webm_source = '';     
  		$ogg_source = '';
  		
      switch(strtolower($video_type['ext'])) {
         case 'flv':  $flv_source = '<source src="'.$video_url.'" type=\'video/flv\' />';
                      break;
         case 'mp4':
         case 'm4v':  $mp4_source = '<source src="'.$video_url.'" type=\'video/mp4\' />';
                      break;
         case 'webm': $webm_source = '<source src="'.$video_url.'" type=\'video/webm; codecs="vp8, vorbis"\' />';
                      break;
         case 'ogg':  $ogg_source = '<source src="'.$video_url.'" type=\'video/ogg; codecs="theora, vorbis"\' />';
                      break;
      }
            

      $poster_attribute = ' poster="'.esc_html__(videopress_post_thumbnail_img_src($post_id, 'imwb-videopress-video-preview')).'"';
      
      // Preload the video
      $preload_attribute = 'preload="auto"';
      
      // Autoplay the video?
      if (videopress_get_option('autoplay') == '1')
      	$autoplay_attribute = " autoplay";
      else
      	$autoplay_attribute = "";
        
      
      $videojs = <<<_end_
      
      <!-- Begin Video.js -->
      <video id="{$id}" class="video-js vjs-default-skin" width="600" height="400" {$poster_attribute} controls {$preload_attribute}{$autoplay_attribute} data-setup="{}">
         {$flv_source}
      	{$mp4_source}
      	{$webm_source}
      	{$ogg_source}
      </video>
      <!-- End Video.js -->
      
_end_;
      
      return $videojs;
  }
  
  function videopress_video_youtube($video_url, $post_id) {
     global $videopress_swfobject;
     
     $video_id = videopress_get_video_id('Y', $video_url);
      
  	  $color1 = $color2 = $border = $autoplay = $loop = $showsearch = $showinfo = $hd = '';
  
     $color1 = '&color1=0x666666';
     $color2 = '&color2=0xEFEFEF';
	  $border = '&border=1';
	  $autoplay = '&autoplay='.videopress_get_option('autoplay');
	  $hd = '&hd=1';  
	  $modestbranding = '&modestbranding='.videopress_get_option('ytmodestbrand');

  	  return '<iframe class="youtube-player" type="text/html" width="600" height="400" src="http://www.youtube.com/embed/'.$video_id.'?rel=0&fs=1&showsearch=0&showinfo=0'.$autoplay.$hd.$border.$color1.$color2.$modestbranding.'" frameborder="0">
  	  	  </iframe>';
  	}
  	
  	function videopress_video_vimeo($video_url, $post_id) {
  	 
  	    $video_id = videopress_get_video_id('V', $video_url);

  	    $objectid = 'video_id_'.rand();
  	    $autoplay = '&amp;autoplay='.videopress_get_option('autoplay');
  	    
  	    return '<span style="width:600px;height:400px;"><iframe id="' . $objectid . '" src="http://player.vimeo.com/video/'.$video_id.'?title=0&amp;byline=0&amp;portrait=0&amp;color=f20511'.$autoplay.'" width="600" height="400" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe> </span>';
  	
  	}
  	
 	function videopress_video_dailymotion($video_url, $post_id) {
 	   global $videopress_swfobject;
 	   
 	   $video_id = videopress_get_video_id('D', $video_url);
 	   $objectid = 'video_id_'.rand();
 	   
 	   $autoplay = '&autoPlay='.videopress_get_option('autoplay');
 	   
// 	   $videopress_swfobject = array( 'width' => '600', 'height' => '400', 'url' => 'http://www.dailymotion.com/swf/' . $video_id . '&colors=background:DEDEDE;glow:FFFFFF;foreground:333333;special:FFC300;' . $autoplay . '&related=0',
//    	   'objectid' => $objectid  );
// 	   
// 	   return '<span style="width:600px;height:400px;"><span id="' . $objectid . '"><a href="http://www.dailymotion.com/video/' . $video_id . '">http://www.dailymotion.com/video/' . $video_id . '</a></span></span>';
 	   
 	   return '<iframe frameborder="0" width="600" height="400" src="http://www.dailymotion.com/embed/video/' . $video_id . '?logo=0&hideInfos=1'.$autoplay.'"></iframe>';
 	   
 	}
 	
 	function videopress_video_metacafe($video_url, $post_id) {
      global $videopress_swfobject;
      
      $video_id = videopress_get_video_id('M', $video_url);
      $objectid = 'video_id_'.rand(); 	
      $autoplay = videopress_get_option('autoplay') == '0' ? 'no' : 'yes';
      
      $videopress_swfobject = array( 'width' => '600', 'height' => '400', 'url' => 'http://www.metacafe.com/fplayer/' . $video_id . '/imwb_videopress_player.swf', 'flashvars' => array('playerVars=autoPlay' => $autoplay),
         'objectid' => $objectid  );
      
      return '<span style="width:600px;height:400px;"><span id="' . $objectid . '"><a href="http://www.metacafe.com/watch/' . $video_id . '/">http://www.metacafe.com/watch/' . $video_id . '/</a></span></span>';
 	}
 	
 function videopress_head() {
   
//      imwb_videopress_open_graph_head();
 ?>     
 <script type="text/javascript">
 // <![CDATA[
 	var imwbvp_flashvars = {};
 //	var imwbvp_params = { wmode: "opaque", allowfullscreen: "true", allowscriptaccess: "always", allownetworking: "internal" };
 	var imwbvp_params = { wmode: "opaque", allowfullscreen: "true", allowscriptaccess: "always"};
 	var imwbvp_attributes = {};
 	var imwbvp_expressinstall = "<?php echo get_template_directory_uri(); ?>/assets/expressinstall.swf";
 	var imwbvp_ajaxurl = '<?php echo admin_url( 'admin-ajax.php' );?>';
 // ]]>
 </script>
 <?php
    if(is_single()) {
 ?>   
    <link href="<?php echo plugins_url(basename( dirname( __FILE__))); ?>/assets/video-js.css" rel="stylesheet">
    <script src="<?php echo plugins_url(basename( dirname( __FILE__))); ?>/assets/video.min.js"></script>
 <?php   
    } 

 }	

 function videopress_footer() {
      global $videopress_swfobject;

      if ( is_feed() || empty($videopress_swfobject) )
         return;
    
  		$content = "\n<script type=\"text/javascript\">\n";
  
  		$content .= '	swfobject.embedSWF("' . ( $videopress_swfobject['url'] ) . '", "' . $videopress_swfobject['objectid'] . '", "600", "400", "10", imwbvp_expressinstall, ';
  
  			if ( empty($videopress_swfobject['flashvars']) || !is_array($videopress_swfobject['flashvars']) ) {
  				$content .= 'imwbvp_flashvars';
  			} else {
  				$content .= '{ ';
  
  				//$videopress_swfobject['flashvars'] = array_merge( array( 'wmode' => 'opaque', 'allowfullscreen' => 'true', 'allowscriptaccess' => 'always' ), $videopress_swfobject['flashvars'] );
  				$flashvars = array();
  
  				foreach ( $videopress_swfobject['flashvars'] as $property => $value ) {
  					if ( false === $value )
  						continue;
  
  					$flashvars[] = '"' . esc_js( $property ). '": "' . esc_js( $value ) . '"';
  				}
  
  				$content .= implode( ', ', $flashvars );
  				$content .= ' }';
  			}
  
  			$content .= ", imwbvp_params, imwbvp_attributes);\n";
  		$content .= "</script>\n";
  
  		// Clear outputted calls
  		$videopress_swfobject = "";
  
  		echo $content;
  
  }


?>